@@ -1,5 +1,6 @@
 from __future__ import absolute_import
 import os
+import six
 import django
 from .. import views
 from django.db import models
@@ -117,6 +118,16 @@ class BakeryTest(TestCase):
             'build_dir': settings.BUILD_DIR,
         })
         call_command("build", 'bakery.tests.MockDetailView')
+        foobar_path = os.path.join(
+            settings.BUILD_DIR,
+            'static',
+            'foo.bar'
+        )
+        self.assertTrue(os.path.exists(foobar_path))
+        self.assertEqual(
+            open(foobar_path, 'rb').read().strip(),
+            'Hello tests'
+        )
         robots_path = os.path.join(settings.BUILD_DIR, 'robots.txt')
         self.assertTrue(os.path.exists(robots_path))
         favicon_path = os.path.join(settings.BUILD_DIR, 'favicon.ico')
@@ -132,6 +143,17 @@ class BakeryTest(TestCase):
     def test_unbuild_cmd(self):
         call_command("unbuild")
 
+    def test_gzipped(self):
+        if django.VERSION >= (1, 4):
+            with self.settings(BAKERY_GZIP=True):
+                six.print_("testing gzipped files")
+                self.test_models()
+                self.test_template_view()
+                self.test_list_view()
+                self.test_detail_view()
+                self.test_404_view()
+                self.test_build_cmd()
+
     def test_buildserver_cmd(self):
         pass
 
